MagicSetsMode

Enum MagicSetsMode 

pub enum MagicSetsMode {
    Auto,
    On,
    Off,
}
Magic-set rewrite mode for bound recursive deterministic queries.

Variants



Auto

Apply the rewrite when the compiler can prove the supported safe subset.



On

Require the rewrite and fail with a typed diagnostic if it is unsafe.



Off

Disable magic-set rewriting.