pub struct Constraint {
pub authored_index: Option<usize>,
pub body: Vec<BodyLiteral>,
}Expand description
A constraint (:- body)
Fields
Stable index of this constraint in the complete authored program.
body: Vec<BodyLiteral>Body literals whose conjunction must never be satisfiable.
Implementations
Sourceimpl Constraint
impl Constraint
Return the authored identity required by prepared compilation paths.