pub fn build_query_proof_traces(program: &Program) -> Vec<QueryProofTrace>Expand description
Build coarse proof traces that name source rules and source facts per query.
pub fn build_query_proof_traces(program: &Program) -> Vec<QueryProofTrace>Build coarse proof traces that name source rules and source facts per query.