pub fn evaluate_epistemic_literal(
mode: EpistemicMode,
lit: &EpistemicLiteral,
interpretation: &EpistemicInterpretation,
) -> TruthValueExpand description
Evaluate a single parsed epistemic literal against a bounded interpretation.
pub fn evaluate_epistemic_literal(
mode: EpistemicMode,
lit: &EpistemicLiteral,
interpretation: &EpistemicInterpretation,
) -> TruthValueEvaluate a single parsed epistemic literal against a bounded interpretation.