pub fn evaluate_faeel_candidate(
program: &Program,
interpretation: &EpistemicInterpretation,
) -> Result<FaeelCandidateResult>Expand description
Evaluate all epistemic literals in a program under bounded FAEEL fixture semantics.
pub fn evaluate_faeel_candidate(
program: &Program,
interpretation: &EpistemicInterpretation,
) -> Result<FaeelCandidateResult>Evaluate all epistemic literals in a program under bounded FAEEL fixture semantics.