EpistemicInterpretation

Struct EpistemicInterpretation 

pub struct EpistemicInterpretation { /* private fields */ }
Minimal interpretation used by G91/FAEEL distinction fixtures.

Implementations

Source

impl EpistemicInterpretation

pub fn new() -> Self

Create an empty interpretation.

pub fn with_known(self, predicate: impl Into<String>, arity: usize) -> Self

Mark a predicate/arity pair as known.

pub fn with_known_terms( self, predicate: impl Into<String>, terms: Vec<Term>, ) -> Result<Self>

Mark a concrete tuple key as known.

pub fn with_possible(self, predicate: impl Into<String>, arity: usize) -> Self

Mark a predicate/arity pair as possible under G91 compatibility semantics.

pub fn with_possible_terms( self, predicate: impl Into<String>, terms: Vec<Term>, ) -> Result<Self>

Mark a concrete tuple key as possible under G91 compatibility semantics.

pub fn with_rejected(self, predicate: impl Into<String>, arity: usize) -> Self

Mark a predicate/arity pair as rejected by the candidate.

pub fn with_rejected_terms( self, predicate: impl Into<String>, terms: Vec<Term>, ) -> Result<Self>

Mark a concrete tuple key as rejected by the candidate.