pub struct EpistemicSplitExecutableComponent {
pub component: EpistemicDependencyComponent,
pub executable: EpistemicExecutablePlan,
}Expand description
One split component lowered through the production epistemic GPU plan path.
Fields
component: EpistemicDependencyComponentSource dependency component covered by this executable subplan.
executable: EpistemicExecutablePlanGPU contract plus reduced runtime plan for this component.