pub fn is_eligible(hg: &HypergraphRule, context: ExecutorContext) -> boolExpand description
Return true when analyze says the rule is eligible in the
selected executor context.
pub fn is_eligible(hg: &HypergraphRule, context: ExecutorContext) -> boolReturn true when analyze says the rule is eligible in the
selected executor context.