pub struct ParserSession { /* private fields */ }Expand description
Incremental parser cache keyed by source path.
Implementations
Sourceimpl ParserSession
impl ParserSession
Sourcepub fn split_statements(source: &str) -> Vec<StatementUnit>
pub fn split_statements(source: &str) -> Vec<StatementUnit>
Split source text into statement units with byte and line/column spans.
Sourcepub fn parse_path(
&mut self,
path: impl AsRef<Path>,
source: &str,
) -> Result<IncrementalParseResult>
pub fn parse_path( &mut self, path: impl AsRef<Path>, source: &str, ) -> Result<IncrementalParseResult>
Parse source associated with a path, reusing unchanged statement parses.
Sourcepub fn invalidate_module(&mut self, path: impl AsRef<Path>) -> usize
pub fn invalidate_module(&mut self, path: impl AsRef<Path>) -> usize
Invalidate one module path and cached sources that import it by final path segment.
Sourcepub fn cached_source_count(&self) -> usize
pub fn cached_source_count(&self) -> usize
Return the number of cached source files.