pub enum MagicSetStatus {
Disabled,
Applied,
Declined,
}Expand description
Status of a magic-set rewrite attempt.
Variants
Disabled
Rewriting was disabled by source configuration or there was no directive.
Applied
A supported bound recursive query was rewritten.
Declined
auto mode found an unsafe or inapplicable program and left it unchanged.