pub fn rewrite_magic_sets_owned(program: Program) -> Result<MagicSetRewrite>Expand description
rewrite_magic_sets taking the program by value: when magic sets are
off (the default) the program is returned as is, without a clone.
pub fn rewrite_magic_sets_owned(program: Program) -> Result<MagicSetRewrite>rewrite_magic_sets taking the program by value: when magic sets are
off (the default) the program is returned as is, without a clone.