pub struct HelperRelationSpec {
pub name: String,
pub rel_id: RelId,
pub schema: Schema,
pub source_rels: [RelId; 2],
}Expand description
Description of a helper relation introduced by the pass.
Fields
name: StringPredicate name allocated for the helper relation.
rel_id: RelIdRelation identifier allocated for the helper relation.
schema: SchemaOutput schema of the helper relation.
source_rels: [RelId; 2]Pair of source relations extracted into the helper body.