parse_program_reference

Function parse_program_reference 

pub fn parse_program_reference(input: &str) -> Result<Program>
Pure-pest reference parser: the whole source through the grammar, no fast path. parse_program is specified to be observationally equal to this.