pub struct FastParseStats {
pub fast_facts: usize,
pub residual_bytes: usize,
pub fell_back: bool,
}Expand description
How much of a parse the fact fast path handled.
Fields
fast_facts: usizeFacts built without pest.
residual_bytes: usizeBytes of source pest still had to parse (everything but the facts).
fell_back: boolThe residual failed to parse/build, so the whole source was re-parsed by the reference parser (its result is what was returned).