pub struct DifferentiableProofTraceMap { /* private fields */ }Expand description
Collection of differentiable proof traces keyed by stable proof ID.
Implementations
Sourceimpl DifferentiableProofTraceMap
impl DifferentiableProofTraceMap
Sourcepub fn insert(&mut self, spec: ProofTraceSpec) -> u64
pub fn insert(&mut self, spec: ProofTraceSpec) -> u64
Insert a trace and return its stable proof ID.
Sourcepub fn trace(&self, proof_id: u64) -> Option<&ProofTrace>
pub fn trace(&self, proof_id: u64) -> Option<&ProofTrace>
Get one exported trace by proof ID.
Sourcepub fn traces(&self) -> impl Iterator<Item = &ProofTrace>
pub fn traces(&self) -> impl Iterator<Item = &ProofTrace>
Iterate over exported traces.
Sourcepub fn accumulate_binary_logistic_gradients(
&mut self,
targets: &[(String, f64)],
) -> f64
pub fn accumulate_binary_logistic_gradients( &mut self, targets: &[(String, f64)], ) -> f64
Accumulate binary logistic gradients grouped by answer key.
Sourcepub fn apply_gradients(&mut self, learning_rate: f64)
pub fn apply_gradients(&mut self, learning_rate: f64)
Apply accumulated gradients to trace weights.