pub fn analyze_stratification(program: &Program) -> StratificationResultExpand description
Analyze stratification for probabilistic inference Returns detailed information about SCCs and which ones are non-monotone
pub fn analyze_stratification(program: &Program) -> StratificationResultAnalyze stratification for probabilistic inference Returns detailed information about SCCs and which ones are non-monotone