pub struct ExpansionContext<'a> { /* private fields */ }Expand description
Context for inline expansion of user-defined functions.
Implementations
Sourceimpl<'a> ExpansionContext<'a>
impl<'a> ExpansionContext<'a>
Sourcepub fn new(registry: &'a FunctionRegistry, max_depth: u32) -> Self
pub fn new(registry: &'a FunctionRegistry, max_depth: u32) -> Self
Create an expansion context with the given function registry and recursion limit.
Sourcepub fn expand_call(
&mut self,
name: &str,
args: &[ArithExpr],
) -> Result<ArithExpr, FunctionError>
pub fn expand_call( &mut self, name: &str, args: &[ArithExpr], ) -> Result<ArithExpr, FunctionError>
Expand a function call to its body with arguments substituted