#[non_exhaustive]pub enum GroundTermEncodingError {
IntegerOutOfRange {
expected: ScalarType,
value: i64,
},
InvalidBooleanInteger {
value: i64,
},
InvalidBooleanSymbol {
symbol: String,
},
Variable {
name: String,
},
Anonymous,
Aggregate,
TypeMismatch {
expected: ScalarType,
actual: Term,
},
}Expand description
A structured failure produced while encoding a ground term for a scalar column.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IntegerOutOfRange
An integer cannot be represented by the requested scalar type.
Fields

expected: ScalarTypeRequested scalar type.
InvalidBooleanInteger
A boolean integer was neither zero nor one.
InvalidBooleanSymbol
A boolean symbol was neither true nor false.
Variable
A fact contained a named variable instead of a ground term.
Anonymous
A fact contained an anonymous wildcard instead of a ground term.
Aggregate
A fact contained an aggregate expression instead of a ground term.
TypeMismatch
The term form is not supported by the requested scalar type.