pub struct ParseCacheStats {
pub hits: usize,
pub misses: usize,
pub invalidated: usize,
pub module_invalidations: usize,
pub statement_count: usize,
pub full_parse_units: usize,
pub incremental_parse_units: usize,
pub elapsed: Duration,
}Expand description
Cache statistics from one incremental parse.
Fields
hits: usizeNumber of unchanged statements reused from cache.
misses: usizeNumber of statements parsed fresh.
invalidated: usizeNumber of prior cached statements invalidated for this source.
module_invalidations: usizeNumber of cached source files invalidated through module invalidation.
statement_count: usizeTotal statement count in the parsed source.
full_parse_units: usizeFull-parse work estimate, in statement units.
incremental_parse_units: usizeIncremental work estimate, in statement units.
elapsed: DurationWall-clock time spent in the incremental parse call.
Implementations
Sourceimpl ParseCacheStats
impl ParseCacheStats
Sourcepub fn estimated_speedup(&self) -> f64
pub fn estimated_speedup(&self) -> f64
Structural speedup estimate based on avoided statement parses.