HelperRelationSpec

Struct HelperRelationSpec 

pub struct HelperRelationSpec {
    pub name: String,
    pub rel_id: RelId,
    pub schema: Schema,
    pub source_rels: [RelId; 2],
}
Description of a helper relation introduced by the pass.

Fields

name: String

Predicate name allocated for the helper relation.

rel_id: RelId

Relation identifier allocated for the helper relation.

schema: Schema

Output schema of the helper relation.

source_rels: [RelId; 2]

Pair of source relations extracted into the helper body.